local addon = ...;
local L = RAT_Locals;
local RAT = RAT;
local _G = _G;

local escapeCodes = {};
escapeCodes.SUCCESS = "|cFF00FF00";
escapeCodes.FAIL = "|cFFFF0000";

local ccOptions = CreateFrame("Frame", "RAT_CC_Options", InterfaceOptionsFramePanelContainer);
ccOptions.name = "Command Center";
ccOptions.parent = "Raid Attendance Tracker";
ccOptions:Hide();

local addonText = ccOptions:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge");
addonText:SetText(L.ADDON_FULL);
addonText:SetPoint("TOP", 0, -16);

local version = ccOptions:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge");
version:SetText(L.ADDON_VERSION);
version:SetPoint("TOPLEFT", 450, -32);

local author = ccOptions:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge");
author:SetText(L.ADDON_AUTHOR);
author:SetPoint("TOPLEFT", 450, -16);

local title = ccOptions:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge");
title:SetText(L.OPTIONS_COMMAND_CENTER_TITLE);
title:SetPoint("TOPLEFT", 16, -16);

local infoText = ccOptions:CreateFontString(nil, "ARTWORK", "GameFontHighlight");
infoText:SetText();
infoText:SetPoint("TOPLEFT", 40, -85);
infoText:SetWordWrap(true);
infoText:SetJustifyV("TOP");
infoText:SetJustifyH("LEFT");
infoText:SetSize(520, 320);

local undoButton = CreateFrame("Button", "RAT_UndoButton", ccOptions, "UIMenuButtonStretchTemplate");
undoButton:SetSize(130,50);
undoButton:SetPoint("TOPLEFT", 50, -100);
undoButton:SetText(L.OPTIONS_UNDO_BUTTON);
undoButton:SetScript("OnClick", function(self)
	local lastAttending = RAT:GetLastAttending();
	local lastAbsent = RAT:GetLastAbsent();
	local lastAmount = RAT:GetLastAmount();
	if ((next(lastAttending) or next(lastAbsent)) and lastAmount) then
		RAT:Undo(lastAttending, lastAbsent, lastAmount);
	else
		DEFAULT_CHAT_FRAME:AddMessage(escapeCodes.FAIL .. L.ADDON .. L.ERROR_UNDO);
	end
end);

local skipButton = CreateFrame("Button", "RAT_UndoButton", ccOptions, "UIMenuButtonStretchTemplate");
skipButton:SetSize(130,50);
skipButton:SetPoint("TOPLEFT", 50, -170);
skipButton:SetText(L.OPTIONS_SKIP_BUTTON);
skipButton:SetScript("OnClick", function(self)
	StaticPopup_Show ("RAT_SKIP_BUTTON");
end);

local setupButton = CreateFrame("Button", "RAT_SetupButton", ccOptions, "UIMenuButtonStretchTemplate");
setupButton:SetSize(130,50);
setupButton:SetPoint("TOPLEFT", 50, -240);
setupButton:SetText(L.OPTIONS_SETUP_BUTTON);
setupButton:SetScript("OnClick", function(self)
	StaticPopup_Show ("RAT_SETUP_BUTTON");
end);

StaticPopupDialogs["RAT_SKIP_BUTTON"] = {
	text = "Are you sure you want to skip the current or coming raid?",
	button1 = "Yes",
	button2 = "No",
	OnAccept = function()
		RAT:SkipToNextRaidDay();
		RAT:BroadcastSummary();
		RAT_SavedData.Bench = {};
		RAT_SavedData.Summary = {};
	end,
	timeout = 0,
	whileDead = true,
	hideOnEscape = true,
	preferredIndex = 3,  -- avoid some UI taint, see http://www.wowace.com/announcements/how-to-avoid-some-ui-taint/
};

StaticPopupDialogs["RAT_SETUP_BUTTON"] = {
	text = "Are you sure you want to start the setup? It will reset all settings except alts and the attendance database.",
	button1 = "Yes",
	button2 = "No",
	OnAccept = function()
		RAT:InitRaidTimes();
		RAT_SavedOptions.AwardStart = true;
		RAT_SavedOptions.Frequency = 60;
		RAT_SavedOptions.RankingAlgo = "RAT-Algorithm";
		RAT_SavedOptions.PunishCalendar = false;
		RAT_SavedOptions.RaiderRanks = {};
		RAT_SavedData.SetupCompleted = false;
		RAT_SavedData.NextAward = 0;
		RAT:StartSetup();
		InterfaceOptionsFrame:Hide();
	end,
	timeout = 0,
	whileDead = true,
	hideOnEscape = true,
	preferredIndex = 3,  -- avoid some UI taint, see http://www.wowace.com/announcements/how-to-avoid-some-ui-taint/
};

InterfaceOptions_AddCategory(ccOptions);